@@ -1,12 +1,14 @@
-from typing import TypedDict, List as ListT, Tuple, Union, Literal
+from typing import List as ListT
+from typing import Literal, Tuple, TypedDict, Union
 
-from .utils.Classes.RegEx import RegEx
-from .utils.Classes.List import List
-from .utils.Classes.String import String
 from .utils.assert_string import assert_string
+from .utils.Classes.List import List
+from .utils.Classes.RegEx import RegEx
+from .utils.Classes.String import String
 from .utils.merge import merge
 from .utils.to_date import to_date
 
+
 class IsDateOptions(TypedDict):
     format: Union[
         Literal['DD/MM/YYYY'],
